summaryrefslogtreecommitdiff
path: root/spec/unit/provider/directory_spec.rb
diff options
context:
space:
mode:
authorLamont Granquist <lamont@opscode.com>2013-03-25 13:06:41 -0700
committerLamont Granquist <lamont@opscode.com>2013-03-25 13:06:41 -0700
commit9de1da01124e549ac514488d2dc71ffb46c9b57e (patch)
treeb7100ddd1c9eca786d8d5ebf3a9004fe5c214573 /spec/unit/provider/directory_spec.rb
parentdb72ae9f28a3eaf27c8e8af5815f7b030186ef07 (diff)
downloadchef-9de1da01124e549ac514488d2dc71ffb46c9b57e.tar.gz
moar spec test fixes
Diffstat (limited to 'spec/unit/provider/directory_spec.rb')
-rw-r--r--spec/unit/provider/directory_spec.rb36
1 files changed, 18 insertions, 18 deletions
diff --git a/spec/unit/provider/directory_spec.rb b/spec/unit/provider/directory_spec.rb
index 3936525903..0b7d040210 100644
--- a/spec/unit/provider/directory_spec.rb
+++ b/spec/unit/provider/directory_spec.rb
@@ -59,7 +59,7 @@ describe Chef::Provider::Directory do
end
it "describes the access mode as a String of octal integers" do
- File.stub!(:exist?).and_return(true)
+ File.stub!(:exists?).and_return(true)
File.should_receive(:stat).and_return(mock_stat)
@directory.load_current_resource
@directory.current_resource.mode.should == "0755"
@@ -67,7 +67,7 @@ describe Chef::Provider::Directory do
context "when user and group are specified with UID/GID" do
it "describes the current owner and group as UID and GID" do
- File.stub!(:exist?).and_return(true)
+ File.stub!(:exists?).and_return(true)
File.should_receive(:stat).and_return(mock_stat)
@directory.load_current_resource
@directory.current_resource.path.should eql(@new_resource.path)
@@ -81,16 +81,16 @@ describe Chef::Provider::Directory do
end
# Unix only for now. While file security attribute reporting for windows is
# disabled, unix and windows differ in the number of exist? calls that are
# made by the provider.
it "should create a new directory on create, setting updated to true", :unix_only do
@new_resource.path "/tmp/foo"
- File.should_receive(:exist?).exactly(2).and_return(false)
+ File.should_receive(:exists?).at_least(:once).and_return(false)
File.should_receive(:directory?).with("/tmp").and_return(true)
Dir.should_receive(:mkdir).with(@new_resource.path).once.and_return(true)
- @directory.should_receive(:set_all_access_controls)
+ @directory.should_receive(:do_acl_changes)
@directory.stub!(:update_new_file_state)
@directory.run_action(:create)
@directory.new_resource.should be_updated
@@ -103,20 +103,20 @@ describe Chef::Provider::Directory do
end
# Unix only for now. While file security attribute reporting for windows is
# disabled, unix and windows differ in the number of exist? calls that are
# made by the provider.
it "should create a new directory when parent directory does not exist if recursive is true and permissions are correct", :unix_only do
@new_resource.path "/path/to/dir"
@new_resource.recursive true
- File.should_receive(:exist?).with(@new_resource.path).ordered.and_return(false)
+ File.should_receive(:exists?).with(@new_resource.path).ordered.and_return(false)
- File.should_receive(:exist?).with('/path/to').ordered.and_return(false)
- File.should_receive(:exist?).with('/path').ordered.and_return(true)
+ File.should_receive(:exists?).with('/path/to').ordered.and_return(false)
+ File.should_receive(:exists?).with('/path').ordered.and_return(true)
File.should_receive(:writable?).with('/path').ordered.and_return(true)
- File.should_receive(:exist?).with(@new_resource.path).ordered.and_return(false)
+ File.should_receive(:exists?).with(@new_resource.path).ordered.and_return(false)
FileUtils.should_receive(:mkdir_p).with(@new_resource.path).and_return(true)
- @directory.should_receive(:set_all_access_controls)
+ @directory.should_receive(:do_acl_changes)
@directory.stub!(:update_new_file_state)
@directory.run_action(:create)
@new_resource.should be_updated
@@ -131,16 +131,16 @@ describe Chef::Provider::Directory do
end
# Unix only for now. While file security attribute reporting for windows is
# disabled, unix and windows differ in the number of exist? calls that are
# made by the provider.
it "should not create the directory if it already exists", :unix_only do
stub_file_cstats
@new_resource.path "/tmp/foo"
- File.should_receive(:directory?).twice.and_return(true)
+ File.should_receive(:directory?).at_least(:once).and_return(true)
File.should_receive(:writable?).with("/tmp").and_return(true)
- File.should_receive(:exist?).exactly(3).and_return(true)
+ File.should_receive(:exists?).at_least(:once).and_return(true)
Dir.should_not_receive(:mkdir).with(@new_resource.path)
- @directory.should_receive(:set_all_access_controls)
+ @directory.should_receive(:do_acl_changes)
@directory.run_action(:create)
end
@@ -152,14 +152,14 @@ describe Chef::Provider::Directory do
end
it "should raise an exception if it cannot delete the directory due to bad permissions" do
- File.stub!(:exist?).and_return(true)
+ File.stub!(:exists?).and_return(true)
File.stub!(:writable?).and_return(false)
lambda { @directory.run_action(:delete) }.should raise_error(RuntimeError)
end
it "should take no action when deleting a target directory that does not exist" do
@new_resource.path "/an/invalid/path"
- File.stub!(:exist?).and_return(false)
+ File.stub!(:exists?).and_return(false)
Dir.should_not_receive(:delete).with(@new_resource.path)
@directory.run_action(:delete)
@directory.new_resource.should_not be_updated
@@ -168,7 +168,7 @@ describe Chef::Provider::Directory do
it "should raise an exception when deleting a directory when target directory is a file" do
stub_file_cstats
@new_resource.path "/an/invalid/path"
- File.stub!(:exist?).and_return(true)
+ File.stub!(:exists?).and_return(true)
File.should_receive(:directory?).and_return(false)
Dir.should_not_receive(:delete).with(@new_resource.path)
lambda { @directory.run_action(:delete) }.should raise_error(RuntimeError)
@@ -81,16 +81,16 @@ describe Chef::Provider::Directory do
end
# Unix only for now. While file security attribute reporting for windows is
- # disabled, unix and windows differ in the number of exist? calls that are
+ # disabled, unix and windows differ in the number of exists? calls that are
# made by the provider.
it "should create a new directory on create, setting updated to true", :unix_only do
@@ -103,20 +103,20 @@ describe Chef::Provider::Directory do
end
# Unix only for now. While file security attribute reporting for windows is
- # disabled, unix and windows differ in the number of exist? calls that are
+ # disabled, unix and windows differ in the number of exists? calls that are
# made by the provider.
it "should create a new directory when parent directory does not exist if recursive is true and permissions are correct", :unix_only do
@@ -131,16 +131,16 @@ describe Chef::Provider::Directory do
end
# Unix only for now. While file security attribute reporting for windows is
- # disabled, unix and windows differ in the number of exist? calls that are
+ # disabled, unix and windows differ in the number of exists? calls that are
# made by the provider.
it "should not create the directory if it already exists", :unix_only do